# Contributing

This document contains information for contributing to this project.
All contributions are welcome!

## Developing

See the project's [main README](README.md) and [frontend README](frontend/README.md)
files for information on how to set up the development environment and how to run the
application.
